#!/usr/bin/python3
import io
import re
import os
from os.path import dirname, join

from setuptools import setup, find_packages


def read(*names, **kwargs):
    return io.open(join(dirname(__file__), *names), encoding=kwargs.get('encoding', 'utf8')).read()


def get_version():
    with open('system_env/__init__.py', 'r') as f:
        line = f.readline()
        match = re.match(r'__version__ = \'([\d\.]+)\'', line)

        if not match:
            raise ImportError("Can't read the version of system_env")

        version = match.group(1)
        return version


def get_packages(package):
    """
    Return root package and all sub-packages.
    """
    return [
        dirpath for dirpath, dirnames, filenames in os.walk(package)
        if os.path.exists(os.path.join(dirpath, '__init__.py'))
    ]


setup(
    name='system_env',
    version=get_version(),
    description='Light-weight library to extract OS and Portal features.',
    long_description='%s' % (
        re.compile(r'^.. start-badges.*^.. end-badges', re.M | re.S).sub('', read('README.md')),
    ),
    long_description_content_type='text/markdown',
    author='Dave Burkholder',
    author_email='dave@compassfoundation.io',
    url='https://code.compassfoundation.io/console-modules/system_env',
    packages=find_packages(),
    zip_safe=True,
    classifiers=[
        'Intended Audience :: Developers',
        'License :: SAP',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Utilities',
    ],
    keywords=[
        'Linux OS'
        'DrawBridge Portal',
    ],
    # This package is a dependency for many other packages.
    # Installation requirements should be minimal!
    install_requires=[
        'distro',
        'lclazy',
    ],
)
